@@ -6,7 +6,7 @@ func init() {
 		"!":                     "Reads the STDIN and exit number from previous process and not's it's condition",
 		"(":                     "Write a string to the STDOUT without new line",
 		"2darray":               "Create a 2D JSON array from multiple input sources",
-		"(murex named pipe)":    "Reads from a _murex_ named pipe",
+		"(murex named pipe)":    "Reads from a Murex named pipe",
 		"<stdin>":               "Read the STDIN belonging to the parent code block",
 		"=":                     "Evaluate a mathematical function (deprecated)",
 		">>":                    "Writes STDIN to disk - appending contents if file already exists",
@@ -21,7 +21,7 @@ func init() {
 		"alter":                 "Change a value within a structured data-type and pass that change along the pipeline without altering the original source input",
 		"and":                   "Returns `true` or `false` depending on whether multiple conditions are met",
 		"append":                "Add data to the end of an array",
-		"args":                  "Command line flag parser for _murex_ shell scripting",
+		"args":                  "Command line flag parser for Murex shell scripting",
 		"autocomplete":          "Set definitions for tab-completion in the command line",
 		"bexists":               "Check which builtins exist",
 		"bg":                    "Run processes in the background",
@@ -29,7 +29,7 @@ func init() {
 		"cast":                  "Alters the data type of the previous function without altering it's output",
 		"catch":                 "Handles the exception code raised by `try` or `trypipe",
 		"cd":                    "Change (working) directory",
-		"config":                "Query or define _murex_ runtime settings",
+		"config":                "Query or define Murex runtime settings",
 		"continue":              "terminate process of a block within a caller function",
 		"count":                 "Count items in a map, list or array",
 		"cpuarch":               "Output the hosts CPU architecture",
@@ -52,9 +52,9 @@ func init() {
 		"false":                 "Returns a `false` value",
 		"fexec":                 "Execute a command or function, bypassing the usual order of precedence.",
 		"fg":                    "Sends a background process into the foreground",
-		"fid-kill":              "Terminate a running _murex_ function",
-		"fid-killall":           "Terminate _all_ running _murex_ functions",
-		"fid-list":              "Lists all running functions within the current _murex_ session",
+		"fid-kill":              "Terminate a running Murex function",
+		"fid-killall":           "Terminate _all_ running Murex functions",
+		"fid-list":              "Lists all running functions within the current Murex session",
 		"for":                   "A more familiar iteration loop to existing developers",
 		"foreach":               "Iterate through an array",
 		"formap":                "Iterate through a map or other collection of data",
@@ -63,7 +63,7 @@ func init() {
 		"g":                     "Glob pattern matching for file system objects (eg `*.txt`)",
 		"get-type":              "Returns the data-type of a variable or pipe",
 		"get":                   "Makes a standard HTTP request and returns the result as a JSON object",
-		"getfile":               "Makes a standard HTTP request and return the contents as _murex_-aware data type for passing along _murex_ pipelines.",
+		"getfile":               "Makes a standard HTTP request and return the contents as Murex-aware data type for passing along Murex pipelines.",
 		"global":                "Define a global variable and set it's value",
 		"history":               "Outputs murex's command history",
 		"if":                    "Conditional statement to execute different blocks of code depending on the result of the condition",
@@ -79,10 +79,10 @@ func init() {
 		"method":                "Define a methods supported data-types",
 		"msort":                 "Sorts an array - data type agnostic",
 		"mtac":                  "Reverse the order of an array",
-		"murex-docs":            "Displays the man pages for _murex_ builtins",
-		"murex-package":         "_murex_'s package manager",
-		"murex-parser":          "Runs the _murex_ parser against a block of code",
-		"murex-update-exe-list": "Forces _murex_ to rescan $PATH looking for exectables",
+		"murex-docs":            "Displays the man pages for Murex builtins",
+		"murex-package":         "Murex's package manager",
+		"murex-parser":          "Runs the Murex parser against a block of code",
+		"murex-update-exe-list": "Forces Murex to rescan $PATH looking for exectables",
 		"null":                  "null function. Similar to /dev/null",
 		"open-image":            "Renders bitmap image data on your terminal",
 		"open":                  "Open a file with a preferred handler",
@@ -90,7 +90,7 @@ func init() {
 		"or":                    "Returns `true` or `false` depending on whether one code-block out of multiple ones supplied is successful or unsuccessful.",
 		"os":                    "Output the auto-detected OS name",
 		"out":                   "Print a string to the STDOUT with a trailing new line character",
-		"pipe":                  "Manage _murex_ named pipes",
+		"pipe":                  "Manage Murex named pipes",
 		"post":                  "HTTP POST request with a JSON-parsable return",
 		"prefix":                "Prefix a string to every item in a list",
 		"prepend":               "Add data to the start of an array",
@@ -102,17 +102,17 @@ func init() {
 		"regexp":                "Regexp tools for arrays / lists of strings",
 		"right":                 "Right substring every item in a list",
 		"runmode":               "Alter the scheduler's behaviour at higher scoping level",
-		"runtime":               "Returns runtime information on the internal state of _murex_",
+		"runtime":               "Returns runtime information on the internal state of Murex",
 		"rx":                    "Regexp pattern matching for file system objects (eg `.*\\\\.txt`)",
 		"set":                   "Define a local variable and set it's value",
-		"source":                "Import _murex_ code from another file of code block",
+		"source":                "Import Murex code from another file of code block",
 		"struct-keys":           "Outputs all the keys in a structure as a file path",
 		"suffix":                "Prefix a string to every item in a list",
 		"summary":               "Defines a summary help text for a command",
 		"switch":                "Blocks of cascading conditionals",
 		"ta":                    "A sophisticated yet simple way to build an array of a user defined data-type",
 		"tabulate":              "Table transformation tools",
-		"test":                  "_murex_'s test framework - define tests, run tests and debug shell scripts",
+		"test":                  "Murex's test framework - define tests, run tests and debug shell scripts",
 		"time":                  "Returns the execution run time of a command or block",
 		"tmp":                   "Create a temporary file and write to it",
 		"tout":                  "Print a string to the STDOUT and set it's data-type",
@@ -120,7 +120,7 @@ func init() {
 		"true":                  "Returns a `true` value",
 		"try":                   "Handles errors inside a block of code",
 		"trypipe":               "Checks state of each function in a pipeline and exits block on error",
-		"version":               "Get _murex_ version",
+		"version":               "Get Murex version",
 		"while":                 "Loop until condition false",
 
 		"base64": "Encode or decode a base64 string",
